#ifndef ActionFrame_h
#define ActionFrame_h

// $Id: ActionFrame.h,v 1.23 2011/12/08 14:16:06 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/


#include "Counter.h"
#include "CustomProcess.h"
#include "File.h"

#include <QtGui/QCheckBox>
#include <QtGui/QGroupBox>
#include <QtGui/QPushButton>
#include <QtCore/QRegExp>

#include <cassert>
#include <list>
#include <vector>

/*
\class ActionFrame
\brief Set of buttons connected to latex related actions
*/

class ActionFrame: public QGroupBox, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    ActionFrame( QWidget* parent );

    //! destructor
    virtual ~ActionFrame( void )
    { return; }

    //! checkbox enumerations
    enum Type
    {
        LATEX,
        PDFLATEX,
        BIBTEX,
        DVIPS,
        DVIPDF,
        PS2PDF,
        CHECK,
        CLEAN
    };

    private slots:

    //! process Button Pressed SIGNAL
    void _buttonPressed( void );

    //! run next action
    void _run( int code = 0, QProcess::ExitStatus = QProcess::NormalExit );

    //! process exited
    void _error( QProcess::ProcessError );

    //! display stdout in text window
    void _read( void );

    protected:

    //! state
    enum State
    {
        RUNNING,
        IDLE
    };

    //! change state
    void _setState( const State& state );

    //! returns true if button is checked
    bool _isChecked( const Type& type )
    {
        assert( static_cast<unsigned int>(type) < checkbox_.size() );
        assert( checkbox_[type] );
        return checkbox_[type]->isChecked();
    }

    //! update action state
    void _updateActionState( void );

    //! latex
    QStringList _latexCommand( void );

    //! pdflatex
    QStringList _pdfLatexCommand( void );

    //! process to run latex
    QStringList _bibtexCommand( void );

    //! process to run dvips
    QStringList _dviPsCommand( void );

    //! process to run dvips
    QStringList _dviPdfCommand( void );

    //! process to run PS2PDF
    QStringList _psToPdfCommand( void );

    //! check labels
    void _checkLabels( void );

    //! check references
    void _checkReferences( void );

    //! check citations
    void _checkCitations( void );

    //! check citations order
    void _checkCitationOrder( void );

    //! get list of citations recursively
    void _addCitations( std::list<QString>&, const File& );

    //! create new process
    CustomProcess& _newProcess( void );

    //! return current process
    CustomProcess& _process( void )
    {
        assert( process_ );
        return *process_;
    }

    private:

    //! number of checkboxes
    enum { checkBoxCount = 8 };

    //! checkbox names
    static const QString checkBoxNames_[checkBoxCount];

    //!@name regular expressions
    //@{

    //! citations
    QRegExp citationRegExp_;

    //@}
    //! checkboxes container
    QWidget* box_;

    //! checkboxes
    std::vector<QCheckBox*> checkbox_;

    //! actions
    std::list<Type> actions_;

    //! run/abort button
    QPushButton* button_;

    //! true if actions are beeing processed
    State state_;

    //! running process
    CustomProcess *process_;

};

#endif
