#ifndef Application_h
#define Application_h

// $Id: Application.h,v 1.14 2011/12/12 15:32:32 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file    Application.h
\brief   Main Window singleton object
\author  Hugo Pereira
\version $Revision: 1.14 $
\date    $Date: 2011/12/12 15:32:32 $
*/



#include "BaseApplication.h"
#include "Config.h"
#include "CommandLineArguments.h"
#include "Counter.h"

class MainWindow;
class FileList;

/*!
\class   Application
\brief   Main Window singleton object
*/

class Application: public BaseApplication, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

        public:

        //! command line help
        static void usage( void );

    //! constructor
    Application( CommandLineArguments );

    //! destructor
    ~Application( void );

    //! default window title
    const QString MAIN_TITLE;

    //! application manager
    virtual void initApplicationManager( void );

    //! create all widgets
    bool realizeWidget( void );

    //! file list
    FileList& recentFiles( void ) const
    {
        assert( recentFiles_ );
        return *recentFiles_;
    }

    //! retrieves top layout
    MainWindow & mainWindow( void ) const
    {
        assert( mainWindow_ );
        return *mainWindow_;
    }

    protected slots:

    //! configuration
    void _configuration( void );

    //! opens MessageBox about Qt version
    void _about( void )
    { BaseApplication::_about( MAIN_TITLE, VERSION, BUILD_TIMESTAMP ); }

    //! process request from application manager
    virtual bool _processCommand( SERVER::ServerCommand );

    private:

    //! recent files list
    FileList* recentFiles_;

    //! top widget
    MainWindow *mainWindow_;

};

#endif
