// $Id: ConfigurationDialog.cpp,v 1.22 2012/01/03 10:46:48 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "ConfigurationDialog.h"

#include "Application.h"
#include "FileList.h"
#include "GridLayout.h"
#include "IconEngine.h"
#include "BaseIcons.h"
#include "Debug.h"
#include "OptionBrowsedLineEditor.h"
#include "OptionSpinBox.h"
#include "OptionCheckBox.h"
#include "RecentFilesConfiguration.h"
#include "Singleton.h"

#include <QtGui/QGroupBox>
#include <QtGui/QLabel>
#include <QtGui/QLayout>
#include <QtGui/QPushButton>

//_________________________________________________________
ConfigurationDialog::ConfigurationDialog( QWidget* parent ):
BaseConfigurationDialog( parent )
{

    Debug::Throw( "ConfigurationDialog::ConfigurationDialog.\n" );
    setWindowTitle( "Configuration - Textool" );

    // base configuration
    baseConfiguration();
    textEditConfiguration();

    // commands
    QWidget *page( &addPage( IconEngine::get( ICONS::PREFERENCE_FILE_TYPES ), "Applications", "System dependent third-party latex related applications" ) );
    {
        QWidget* box;
        page->layout()->addWidget( box = new QWidget( page ) );

        OptionBrowsedLineEditor* editor;
        GridLayout *gridLayout( new GridLayout() );
        box->setLayout( gridLayout );
        gridLayout->setMargin(0);
        gridLayout->setSpacing(5);
        gridLayout->setMaxCount(2);
        gridLayout->setColumnAlignment(0, Qt::AlignRight|Qt::AlignVCenter );

        gridLayout->addWidget( new QLabel( "Latex: ", box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "LATEX_COMMAND" ) );
        addOptionWidget( editor );

        gridLayout->addWidget( new QLabel( "Bibtex: ", box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "BIBTEX_COMMAND" ) );
        addOptionWidget( editor );

        gridLayout->addWidget( new QLabel( "Dvi to ps: ", box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "DVI_TO_PS" ) );
        addOptionWidget( editor );

        gridLayout->addWidget( new QLabel( "Dvi to pdf: ", box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "DVI_TO_PDF" ) );
        addOptionWidget( editor );

        gridLayout->addWidget( new QLabel( "Postscript to pdf: ", box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "PS_TO_PDF" ) );
        addOptionWidget( editor );

        gridLayout->addWidget( new QLabel( "Ghostscript: ", box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "GS" ) );
        editor->setToolTip(
            "Ghostscript command to run inside dvi_to_pdf. "
            "Set to blanck to use build-in dvi to pdf conversion" );
        addOptionWidget( editor );

        gridLayout->addWidget( new QLabel( "Dvi viewer: ", box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "DVI_VIEWER"  ) );
        addOptionWidget( editor );

        gridLayout->addWidget( new QLabel( "Postscript viewer: ", box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "PS_VIEWER" ) );
        addOptionWidget( editor );

        gridLayout->addWidget( new QLabel( "Pdf viewer: ", box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "PDF_VIEWER" ) );
        addOptionWidget( editor );

        gridLayout->addWidget( new QLabel( "Text editor: ", box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "TEXT_EDITOR" ) );
        addOptionWidget( editor );

        gridLayout->addWidget( new QLabel( "Spell checker: ", box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "SPELLCHECK" ) );
        addOptionWidget( editor );

    }

    // recent files
    page = &addPage( IconEngine::get( ICONS::PREFERENCE_RECENT_FILES ), "Recent Files", "Recent files list settings", true );
    RecentFilesConfiguration* recent_files_configuration = new RecentFilesConfiguration( page, Singleton::get().application<Application>()->recentFiles() );
    page->layout()->addWidget( recent_files_configuration );
    addOptionWidget( recent_files_configuration );

    // load initial configuration
    _read();

}
