// $Id: IncludeFileModel.cpp,v 1.11 2011/12/06 12:57:49 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\File    IncludeFileModel.h
\brief   Job model. Stores job information for display in lists
\author  Hugo Pereira
\version $Revision: 1.11 $
\date    $Date: 2011/12/06 12:57:49 $
*/

#include "IncludeFileModel.h"



//! column titles
const QString IncludeFileModel::columnTitles_[ IncludeFileModel::n_columns ] = { "File", "included" };

//_______________________________________________________________
IncludeFileModel::IncludeFileModel( QObject* parent ):
    TreeModel<IncludeFile>( parent ),
    Counter( "IncludeFileModel" )
{ Debug::Throw( "IncludeFileModel::IncludeFileModel.\n" ); }


//__________________________________________________________________
QVariant IncludeFileModel::data( const QModelIndex& index, int role ) const
{
    Debug::Throw( "IncludeFileModel::data.\n" );

    // check index, role and column
    if( !index.isValid() ) return QVariant();
    if( role == Qt::DisplayRole && index.column() == File ) return _find( index.internalId() ).get().file().localName();
    else if( role == Qt::CheckStateRole && index.column() == Selection )
    {
        if( !parent( index ).isValid() ) return QVariant();
        else return _find( index.internalId() ).get().isSelected() ? Qt::Checked : Qt::Unchecked;
    }

    return QVariant();

}

//__________________________________________________________________
QVariant IncludeFileModel::headerData(int section, Qt::Orientation orientation, int role) const
{

    if(
        orientation == Qt::Horizontal &&
        role == Qt::DisplayRole &&
        section >= 0 &&
        section < n_columns )
    { return columnTitles_[section]; }

    // return empty
    return QVariant();

}
