#ifndef IncludeFileModel_h
#define IncludeFileModel_h

// $Id: IncludeFileModel.h,v 1.7 2011/02/28 15:22:35 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\File    IncludeFileModel.h
\brief   FileRecord model. Store File records in hierarchy list.
\author  Hugo Pereira
\version $Revision: 1.7 $
\date    $Date: 2011/02/28 15:22:35 $
*/

#include "Counter.h"
#include "FileRecord.h"
#include "TreeModel.h"

//! needed to store hierarchical information on top of FileRecord
class IncludeFile: public FileRecord
{
    public:

    //! constructor
    IncludeFile( FileRecord record = FileRecord() ):
        FileRecord( record ),
        selected_( true )
    {}

    //! parent
    const FileRecord& parent( void ) const
    { return parent_; }

    //! set parent
    void setParent( const FileRecord& record )
    { parent_ = record; }

    //! set item selected
    void setSelected( const bool& value )
    { selected_ = value; }

    //! true if selected
    bool isSelected( void ) const
    { return selected_; }

    //! returns true if this record is a child of argument
    bool isChild( const IncludeFile& record ) const
    { return parent_.file() == record.file(); }

    private:

    //! parent File record, if any
    FileRecord parent_;

    //! selected
    bool selected_;

};

//! FileRecord model. Store File records in hierarchy list.
class IncludeFileModel : public TreeModel<IncludeFile>, public Counter
{

    public:

    //! number of columns
    enum { n_columns = 2 };

    //! column type enumeration
    // enum ColumnType { Selection, File };
    enum ColumnType { File, Selection };

    //! constructor
    IncludeFileModel(QObject *parent = 0);

    //! destructor
    virtual ~IncludeFileModel()
    {}

    //!@name methods reimplemented from base class
    //@{

    // return File for a given index
    virtual QVariant data(const QModelIndex &index, int role) const;

    //! header data
    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;

    //! number of columns for a given index
    virtual int columnCount(const QModelIndex &parent = QModelIndex()) const
    { return n_columns; }

    //@}

    protected:

    //! sorting
    virtual void _sort( int column, Qt::SortOrder order = Qt::AscendingOrder )
    {}

    private:

    //! column titles
    static const QString columnTitles_[ n_columns ];

};

#endif
