#ifndef IncludeFrame_h
#define IncludeFrame_h

// $Id: IncludeFrame.h,v 1.20 2012/01/04 10:51:14 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Debug.h"
#include "File.h"
#include "IncludeFileModel.h"
#include "TabWidget.h"
#include "TimeStamp.h"

#include <QtGui/QAction>
#include <QtGui/QPushButton>
#include <QtCore/QRegExp>
#include <QtCore/QFileSystemWatcher>

class TreeView;

//! parse input File and display includes recursively
class IncludeFrame:public TabWidget
{


    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    IncludeFrame( QTabWidget* parent = 0 );

    //! include files
    IncludeFileModel::List files( void ) const
    { return model_.children(); }

    //! selected files
    IncludeFileModel::List selection( void ) const;

    //! check if files are modified
    bool filesModified( void );

    signals:

    //! emmited when list of include files have been updated
    void updated( IncludeFileModel::List );

    public slots:

    //! update using Application File as a base
    void update( void );

    protected slots:

    //! update actions enability
    void _updateActions( void );

    //! toggle (check/uncheck) item
    void _toggle( const QModelIndex& );

    //! update buttons
    void _updateButtons( void );

    //! edit a File from list view
    void _edit( void );

    //! run spell checker on a File
    void _spellCheck( void );

    //! check all
    void _selectAll( void );

    //! uncheck all
    void _selectNone( void );

    //! invert selection
    void _invert( void );

    protected:

    //! list
    TreeView& _list( void ) const
    {
        assert( list_ );
        return *list_;
    }

    //! parse File
    void _parseFile( const IncludeFile& File );

    //! returns true if file is on afs
    bool _fileIsAfs( const QString& ) const;

    private:

    //! model
    IncludeFileModel model_;

    //! list
    TreeView* list_;

    //! input File tag
    QRegExp includeRegexp_;

    //! comments regexp
    QRegExp commentRegexp_;

    //! set of included files (needed for recursivity)
    IncludeFileModel::Set includes_;

    //! file system watcher
    QFileSystemWatcher fileSystemWatcher_;

    //! last update
    TimeStamp lastUpdate_;

    //!@name actions
    //@{

    //! edit
    QAction* editAction_;

    //! run spellcheck
    QAction* spellcheckAction_;

    //@}

    //!@name buttons
    //@{

    //! button widget
    QWidget* buttonWidget_;

    //! select all
    QPushButton* selectAllButton_;

    //! deselect
    QPushButton* selectNoneButton_;

    //! invert
    QPushButton* invertButton_;

    //! edit
    QPushButton* editButton_;

    //! spell check
    QPushButton* spellCheckButton_;

    //@}

};

#endif
