// $Id: TexString.cpp,v 1.11 2012/01/02 15:39:22 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "TexString.h"
#include "File.h"

//________________________________________________________
const QString& TexString::header( void )
{
    static const QString header_(
        "\\NeedsTeXFormat{LaTeX2e}\n"
        "\\documentclass[10pt,a4paper]{article}\n"
        "\\usepackage[latin1]{inputenc}\n"
        "\\usepackage[T1]{fontenc}\n"
        "\n"
        "\\hoffset 0.cm\n"
        "\\voffset 1.cm\n"
        "\\oddsidemargin 0.cm\n"
        "\\evensidemargin 0.cm\n"
        "\\topmargin 0.cm\n"
        "\\headheight 0.mm\n"
        "\\headsep 0.mm\n"
        "\\textheight 23.cm\n"
        "\\textwidth 16.2cm\n"\
        "\\marginparsep 0.cm\n"
        "\\marginparwidth 0.cm\n"
        "\\footskip 1.cm\n"
        "\\parskip 3mm\n"
        "\\parindent 0mm\n"
        "\n"
        "\\begin{document}\n");
    return header_;
}

//________________________________________________________
const QString& TexString::trailer( void )
{
    static const QString trailer_( "\n\\end{document}\n" );
    return trailer_;
}

//________________________________________________________
QString TexString::addExtension( const QString& extension )
{

    // prepare output file
    QString out( *this );

    // remove file extension, if found:
    if( extensions().find(  File( *this ).extension() ) != extensions().end() )
    { out = File( *this ).truncatedName(); }

    // adds new extension
    out += extension;
    return out;
}

//________________________________________________________
const TexString::ExtensionList& TexString::extensions( void )
{
    static ExtensionList extensions_;
    if( extensions_.empty() )
    {

        extensions_.insert( "tex" );
        extensions_.insert( "dvi" );
        extensions_.insert( "ps" );
        extensions_.insert( "pdf" );
        extensions_.insert( "aux" );
        extensions_.insert( "log" );
        extensions_.insert( "out" );
        extensions_.insert( "toc" );
        extensions_.insert( "tof" );
        extensions_.insert( "bib" );
        extensions_.insert( "bbl" );
        extensions_.insert( "blg" );
    }

    return extensions_;

}

//________________________________________________________
const TexString::ExtensionList& TexString::cleanExtensions( void )
{
    static ExtensionList clean_extensions_;
    if( clean_extensions_.empty() )
    {

        clean_extensions_.insert( "dvi" );
        clean_extensions_.insert( "aux" );
        clean_extensions_.insert( "log" );
        clean_extensions_.insert( "out" );
        clean_extensions_.insert( "toc" );
        clean_extensions_.insert( "tof" );
        clean_extensions_.insert( "bbl" );
        clean_extensions_.insert( "blg" );
    }

    return clean_extensions_;

}

//________________________________________________________
const TexString::ConversionList& TexString::conversions( void )
{
    static ConversionList conversions_;

    if( conversions_.empty() )
    {
        conversions_.push_back( std::make_pair( "", "\\`a" ) );
        conversions_.push_back( std::make_pair( "", "\\^a" ) );
        conversions_.push_back( std::make_pair( "", "\\\"a" ) );
        conversions_.push_back( std::make_pair( "", "\\'e" ) );
        conversions_.push_back( std::make_pair( "", "\\`e" ) );
        conversions_.push_back( std::make_pair( "", "\\^e" ) );
        conversions_.push_back( std::make_pair( "", "\\\"e" ) );
        conversions_.push_back( std::make_pair( "", "\\^\\i" ) );
        conversions_.push_back( std::make_pair( "", "\\\"\\i" ) );
        conversions_.push_back( std::make_pair( "", "\\^o" ) );
        conversions_.push_back( std::make_pair( "", "\\\"o" ) );
        conversions_.push_back( std::make_pair( "", "\\`u" ) );
        conversions_.push_back( std::make_pair( "", "\\^u" ) );
        conversions_.push_back( std::make_pair( "", "\\c c" ) );
        // (wtf) conversions_.push_back( std::make_pair( "?", "-" ) );
    }

    return conversions_;

}
