// $Id: TexString.h,v 1.8 2011/10/13 11:20:22 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#ifndef TexString_h
#define TexString_h

/*!
\file    TexString.h
\brief   some tex related utilities
\author  Hugo Pereira
\version $Revision: 1.8 $
\date    $Date: 2011/10/13 11:20:22 $
*/

#include <QString>
#include <list>
#include <map>
#include <set>


/*!
\class   TexString
\brief   some tex related utilities
*/

class TexString: public QString
{

    public:

    //! constructor
    TexString( const QString& value ):
        QString( value )
    {}

    //! add extension
    QString addExtension( const QString& );

    //! extension list
    typedef std::set< QString > ExtensionList;

    //! extensions
    static const ExtensionList& extensions( void );

    //! clean extensions
    /*! these are extension of files that gets removed when clean action is pressed */
    static const ExtensionList& cleanExtensions( void );

    //! latex header
    static const QString& header();

    //! latex header
    static const QString& trailer();

    //! conversions
    typedef std::pair<QString, QString> Conversion;

    //! conversions
    typedef std::list< Conversion > ConversionList;

    //! conversions
    static const ConversionList& conversions( void );

};

#endif
