#ifndef _WindowTitle_h_
#define _WindowTitle_h_
// $Id: WindowTitle.h,v 1.4 2009/09/09 02:29:48 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
   \file WindowTitle.h
   \brief Generate window title from filename
   \author Hugo Pereira
   \version $Revision: 1.4 $
   \date $Date: 2009/09/09 02:29:48 $
*/

#include <QString>
#include <QTextStream>

#include "Counter.h"
#include "File.h"

class WindowTitle: public Counter
{

  public:

  //! Flags
  enum Flags
  {
    NONE,
    MODIFIED,
    READ_ONLY
  };

  //! constructor
  WindowTitle( const File& file, const Flags& flag = NONE ):
    Counter( "WindowTitle" ),
    file_( file ),
    flag_( flag )
  {}

  //! cast to string
  operator QString (void ) const
  {
    QString buffer;
    QTextStream what( &buffer );
    if( file_.size() ) what << file_.localName();
    else what << "TexTool";
    if( flag_ == MODIFIED ) what << " (modified)";
    if( flag_ == READ_ONLY ) what << " (read-only)";
    if( file_.size() ) what << " - " << file_.path();
    return buffer;
  }

  private:

  //! filename
  File file_;

  //! flags
  Flags flag_;

};

#endif
